﻿Imports ThinkGeo.MapSuite.Core
Imports ThinkGeo.MapSuite.DesktopEdition
Imports GetPerimeterDemo.CoordSysEnums
Imports System.Collections.ObjectModel
Public Class Form1
   Private WithEvents moMap As WinformsMap
   Private moShapefile As ShapeFileFeatureLayer
   Public Sub New()
      InitializeComponent()

      moMap = New WinformsMap
      moMap.Dock = DockStyle.Fill
      Controls.Add(moMap)

   End Sub

   Private Sub Form1_Load(sender As Object, e As System.EventArgs) Handles Me.Load
      Dim sPath As String = "..\..\Data\Alabama.shp"
      moShapefile = New ShapeFileFeatureLayer(sPath, ShapeFileReadWriteMode.ReadWrite)
      moShapefile.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.SimpleColors.Transparent, GeoColor.SimpleColors.Blue, 2)
      moShapefile.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20

      Dim oOverlay As New LayerOverlay
      oOverlay.Layers.Add(moShapefile)

      moMap.Overlays.Add(oOverlay)
      moMap.MapUnit = GeographyUnit.Meter
      moShapefile.Open()
      moMap.CurrentExtent = moShapefile.GetBoundingBox
      moMap.Refresh()

      btnSwitchCoordSys.Text = "Change to WGS84"

   End Sub
   Private Sub mSetCoordinateSystem(eSrid As EnumCoordSys)
      If eSrid = EnumCoordSys.None Then
         '***** Remove the coordinate system from the map and from the layer
         moShapefile.FeatureSource.Projection = Nothing
         moMap.MapUnit = GeographyUnit.Meter
         btnSwitchCoordSys.Text = "Change to WGS84"
      Else
         '***** Apply a geographic coordinate system to the layer and the map
         Dim oProj4 As New ManagedProj4Projection(
                           ManagedProj4Projection.GetEsriParametersString(EnumCoordSys.NAD83_UTM_zone_16N),
                           ManagedProj4Projection.GetEsriParametersString(eSrid))
         oProj4.Open()
         moShapefile.FeatureSource.Projection = oProj4
         moMap.MapUnit = GeographyUnit.DecimalDegree
         btnSwitchCoordSys.Text = "Change to NAD83 16N"
      End If
      moShapefile.Open()
      moMap.CurrentExtent = moShapefile.GetBoundingBox
      moMap.Refresh()
   End Sub

   Private Sub btnSwitchCoordSys_Click(sender As Object, e As System.EventArgs) Handles btnSwitchCoordSys.Click
      If btnSwitchCoordSys.Text = "Change to NAD83 16N" Then
         mSetCoordinateSystem(EnumCoordSys.None)
      Else
         mSetCoordinateSystem(EnumCoordSys.WGS_84)
      End If
   End Sub

   Private Sub moMap_MapClick(sender As Object, e As ThinkGeo.MapSuite.DesktopEdition.MapClickWinformsMapEventArgs) Handles moMap.MapClick
      '***** Get the feature clicked on
      Dim oFeatures As Collection(Of Feature) = moShapefile.QueryTools.GetFeaturesContaining(e.WorldLocation, ReturningColumnsType.NoColumns)
      Dim dPerimeter As Double
      Dim dArea As Double
      Dim oFeature As Feature

      txtArea.Text = String.Empty
      txtArea.Refresh()
      txtPerimeter.Text = String.Empty
      txtPerimeter.Refresh()
      Me.Cursor = Cursors.WaitCursor

      If oFeatures.Count > 0 Then
         oFeature = oFeatures(0)

         dArea = CType(oFeature.GetShape, AreaBaseShape).GetArea(moMap.MapUnit, AreaUnit.SquareMiles)

         txtArea.Text = String.Format("{0:#,##0.00} sq miles", dArea)
         txtArea.Refresh()
         Dim oStopWatch As New System.Diagnostics.Stopwatch

         oStopWatch.Start()

         dPerimeter = CType(oFeature.GetShape, AreaBaseShape).GetPerimeter(moMap.MapUnit, DistanceUnit.Mile)

         txtPerimeter.Text = String.Format("{0:#,##0.00} miles", dPerimeter)
         txtPerimeter.Refresh()

         oStopWatch.Stop()
         MessageBox.Show(String.Format("Time to get perimeter: {0:#,##0.00} seconds", oStopWatch.ElapsedMilliseconds / 1000))
      End If

      Me.Cursor = Cursors.Default
   End Sub
End Class
